npstructures package
====================

Submodules
----------

npstructures.arrayfunctions module
----------------------------------

.. automodule:: npstructures.arrayfunctions
   :members:
   :undoc-members:
   :show-inheritance:

npstructures.hashtable module
-----------------------------

.. automodule:: npstructures.hashtable
   :members:
   :undoc-members:
   :show-inheritance:

npstructures.raggedarray module
-------------------------------

.. automodule:: npstructures.raggedarray
   :members:
   :undoc-members:
   :show-inheritance:

npstructures.raggedshape module
-------------------------------

.. automodule:: npstructures.raggedshape
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: npstructures
   :members:
   :undoc-members:
   :show-inheritance:
